import * as React from 'react';
import { DelayedTask } from '../../util';
import { TranslatorT } from '../../translation';
import { ISettings } from '../../settings';
import { IDateConverter, INumberConverter } from '../../converter';
import { IUniversalComponentPlugin, IUniversalComponent, IUniversalComponentPluginClassEntity } from '../../entities-definitions.interface';
import { IUniversalComponentProps } from '../../props-definitions.interface';
import { IUIFactory } from '../factory/factory.interface';
import { IDomAccessor } from '../dom-accessor/dom-accessor.interface';
import { IStorage, ITransport } from '../../definition';
export declare class UniversalComponent<TProps extends IUniversalComponentProps = IUniversalComponentProps, TState = {}> extends React.PureComponent<TProps, TState> implements IUniversalComponent<TProps, TState> {
    protected readonly plugins: IUniversalComponentPlugin[];
    protected scrollTask: DelayedTask;
    protected readonly selfRef: React.RefObject<any>;
    private readonly defaultUiFactory;
    /**
     * @stable [23.04.2018]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [23.04.2018]
     */
    componentDidMount(): void;
    /**
     * @stable [18.12.2018]
     * @param {Readonly<TProps extends IUniversalComponentProps>} prevProps
     * @param {Readonly<TState>} prevState
     */
    getSnapshotBeforeUpdate(prevProps: Readonly<TProps>, prevState: Readonly<TState>): void;
    /**
     * @stable [23.04.2018]
     */
    componentWillUnmount(): void;
    /**
     * @stable [23.04.2018]
     * @param {Readonly<TProps>} prevProps
     * @param {Readonly<TState>} prevState
     * @param {never} prevContext
     */
    componentDidUpdate(prevProps: Readonly<TProps>, prevState: Readonly<TState>, prevContext?: never): void;
    /**
     * @stable [01.12.2018]
     * @returns {Element}
     */
    getSelf(): Element;
    /**
     * @stable [01.12.2018]
     */
    protected onNativeScroll(): void;
    /**
     * @stable [01.12.2018]
     */
    protected doScroll(): void;
    /**
     * @stable [19.04.2018]
     * @returns {TranslatorT}
     */
    protected readonly t: TranslatorT;
    /**
     * @reactNativeCompatible
     * @stable [29.07.2019]
     * @returns {ISettings}
     */
    protected readonly settings: ISettings;
    /**
     * @reactNativeCompatible
     * @stable [29.07.2019]
     * @returns {IStorage}
     */
    protected readonly databaseStorage: IStorage;
    /**
     * @stable [13.05.2018]
     * @returns {IDateConverter}
     */
    protected readonly dc: IDateConverter;
    /**
     * @stable [13.05.2018]
     * @returns {INumberConverter}
     */
    protected readonly nc: INumberConverter;
    /**
     * @stable [18.05.2018]
     * @returns {IUIFactory}
     */
    protected readonly uiFactory: IUIFactory;
    /**
     * @stable [01.12.2018]
     * @returns {IDomAccessor}
     */
    protected readonly domAccessor: IDomAccessor;
    /**
     * @reactNativeCompatible
     * @stable [15.09.2019]
     * @returns {ITransport}
     */
    protected readonly transport: ITransport;
    /**
     * @stable [18.06.2019]
     * @param {IUniversalComponentPluginClassEntity | IUniversalComponentPlugin} pluginObject
     */
    protected registerPlugin(pluginObject: IUniversalComponentPluginClassEntity | IUniversalComponentPlugin): void;
    /**
     * @stable [18.06.2019]
     */
    private initPlugins;
    /**
     * @reactNativeCompatible
     * @stable [21.08.2019]
     * @returns {Map<IUniversalComponentClassEntity, UniversalComponentPluginFactoryT>}
     */
    private readonly uiPlugins;
}
