import * as React from 'react';
import { Store } from 'redux';
import { IKeyValue, AnyT } from '../../definitions.interface';
import { IContainerClassEntity, IUniversalContainer, IUniversalStoreEntity } from '../../entities-definitions.interface';
import { IOperationEntity, IUniversalContainerProps } from '../../definition';
import { IConnectorConfigEntity, IRoutesConfiguration } from '../../configurations-definitions.interface';
import { ISettings } from '../../settings';
import { TranslatorT } from '../../translation';
import { IDateConverter, INumberConverter } from '../../converter';
import { IAuthService } from '../../auth';
import { IUIFactory } from '../factory/factory.interface';
export declare class UniversalContainer<TProps extends IUniversalContainerProps = IUniversalContainerProps, TState = {}> extends React.PureComponent<TProps, TState> implements IUniversalContainer<TProps, TState> {
    private static readonly uLogger;
    private $dc;
    private $ts;
    /**
     * @stable - 12.04.2018
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [18.11.2018]
     * @param {string} type
     * @param {TChanges} data
     */
    dispatch<TChanges = IKeyValue>(type: string, data?: TChanges): void;
    /**
     * @stable [24.02.2019]
     * @param {string} type
     * @param {TData} data
     * @param {string} otherSection
     */
    dispatchFrameworkAction<TData = IKeyValue>(type: string, data?: TData, otherSection?: string): void;
    /**
     * @stable - 12.04.2018
     * @param {TPath0} path
     * @param {TState0} state
     */
    navigate<TPath0, TState0>(path: TPath0, state?: TState0): void;
    /**
     * @stable [14.01.2019]
     * @param {TPath0} path
     * @param {TState0} state
     */
    navigateAndRewrite<TPath0, TState0>(path: TPath0, state?: TState0): void;
    /**
     * @stable [24.02.2019]
     * @param {TChanges} changes
     * @param {string} otherSection
     */
    dispatchFormChanges<TChanges extends IKeyValue = IKeyValue>(changes: TChanges, otherSection?: string): void;
    /**
     * @stable [24.02.2019]
     * @param {string} fieldName
     * @param {AnyT} fieldValue
     * @param {string} otherSection
     */
    dispatchFormChange(fieldName: string, fieldValue?: AnyT, otherSection?: string): void;
    /**
     * @stable [18.11.2018]
     * @param {string} dictionary
     * @param {TData} data
     */
    dispatchLoadDictionary<TData = IKeyValue>(dictionary: string, data?: TData): void;
    /**
     * @stable [23.12.2018]
     * @param {string} type
     * @param {TData} data
     */
    dispatchCustomType<TData = IKeyValue>(type: string, data?: TData): void;
    /**
     * @stable - 12.04.2018
     */
    protected navigateToBack(): void;
    /**
     * @stable [27.12.2018]
     * @param {string | IOperationEntity} operation
     * @returns {boolean}
     */
    protected isTransportContainsExecutingOperation(operation: string | IOperationEntity): boolean;
    /**
     * @stable [26.08.2018]
     * @param {string} fieldName
     */
    protected dispatchFormClear(fieldName: string): void;
    /**
     * @stable [09.09.2019]
     */
    protected overrideRenderMethod(): void;
    /**
     * @stable [09.09.2019]
     * @param e
     * @returns {React.ReactNode}
     */
    protected prepareGlobalErrorScreen(e: any): React.ReactNode;
    /**
     * @stable - 15.04.2018
     * @returns {Store<{}>}
     */
    protected readonly appStore: Store<IUniversalStoreEntity>;
    /**
     * @stable - 15.04.2018
     * @returns {Map<IContainerClassEntity, IConnectorConfigEntity>}
     */
    protected readonly dynamicRoutes: Map<IContainerClassEntity, IConnectorConfigEntity>;
    /**
     * @stable - 15.04.2018
     * @returns {IRoutesConfiguration}
     */
    protected readonly routes: IRoutesConfiguration;
    /**
     * @stable [26.04.2018]
     * @returns {IAuthService}
     */
    protected readonly auth: IAuthService;
    /**
     * @reactNativeCompatible
     * @stable [23.05.2019]
     * @returns {TranslatorT}
     */
    protected readonly t: TranslatorT;
    /**
     * ReactNative supporting
     *
     * @stable [23.05.2019]
     * @returns {IDateConverter}
     */
    protected readonly dc: IDateConverter;
    /**
     * @stable [14.01.2019]
     * @param {string} action
     * @param {TPath0} path
     * @param {TState0} state
     */
    private doNavigate;
    /**
     * @reactNativeCompatible
     * @stable [23.05.2019]
     * @returns {ISettings}
     */
    protected readonly settings: ISettings;
    /**
     * @reactNativeCompatible
     * @stable [28.08.2019]
     * @returns {INumberConverter}
     */
    protected readonly nc: INumberConverter;
    /**
     * @reactNativeCompatible
     * @stable [28.08.2019]
     * @returns {IUIFactory}
     */
    protected readonly uiFactory: IUIFactory;
}
