"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var base_1 = require("../base");
var button_1 = require("../button");
var layout_1 = require("../layout");
var util_1 = require("../../util");
var title_1 = require("../title");
var Dialog = /** @class */ (function (_super) {
    __extends(Dialog, _super);
    /**
     * @stable [04.10.2018]
     * @param {TProps} props
     */
    function Dialog(props) {
        var _this = _super.call(this, props) || this;
        _this.onAccept = _this.onAccept.bind(_this);
        _this.onClose = _this.onClose.bind(_this);
        return _this;
    }
    /**
     * @stable [03.08.2018]
     * @returns {JSX.Element}
     */
    Dialog.prototype.render = function () {
        return (React.createElement("div", { ref: this.selfRef, className: this.getDialogClassName() },
            this.dialogBodyElement,
            this.isDialogVisible() && (React.createElement("div", { className: util_1.toClassName('rac-dialog-scrim', this.uiFactory.dialogScrim) }))));
    };
    /**
     * @stable [19.06.2019]
     */
    Dialog.prototype.activate = function () {
        // Each plugin must override this method
    };
    /**
     * @stable [17.05.2018]
     */
    Dialog.prototype.onAccept = function () {
        var props = this.props;
        if (props.onAccept) {
            props.onAccept();
        }
    };
    /**
     * @stable [17.06.2019]
     */
    Dialog.prototype.onClose = function () {
        var props = this.props;
        if (props.onClose) {
            props.onClose();
        }
    };
    /**
     * @stable [19.06.2019]
     */
    Dialog.prototype.onDeactivate = function () {
        var props = this.props;
        if (util_1.isFn(props.onDeactivate)) {
            props.onDeactivate();
        }
    };
    Object.defineProperty(Dialog.prototype, "acceptable", {
        /**
         * @stable [17.05.2018]
         * @returns {boolean}
         */
        get: function () {
            return this.props.acceptable !== false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "closable", {
        /**
         * @stable [17.05.2018]
         * @returns {boolean}
         */
        get: function () {
            return this.props.closable !== false;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [05.08.2018]
     * @returns {string}
     */
    Dialog.prototype.getDialogClassName = function () {
        return util_1.toClassName('rac-dialog', this.props.className, this.uiFactory.dialog, !this.isDialogVisible() && 'rac-invisible');
    };
    /**
     * @stable [03.08.2018]
     * @returns {boolean}
     */
    Dialog.prototype.isCloseButtonDisabled = function () {
        return this.props.closeDisabled;
    };
    /**
     * @stable [03.08.2018]
     * @returns {boolean}
     */
    Dialog.prototype.isAcceptButtonDisabled = function () {
        return this.props.acceptDisabled;
    };
    /**
     * @stable [04.08.2018]
     * @returns {boolean}
     */
    Dialog.prototype.isDialogVisible = function () {
        return true;
    };
    Object.defineProperty(Dialog.prototype, "dialogBodyElement", {
        /**
         * @stable [17.06.2019]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement(layout_1.FlexLayout, { className: util_1.toClassName('rac-dialog-body', this.uiFactory.dialogContainer) },
                this.bodyElement,
                this.footerElement));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "bodyElement", {
        /**
         * @stable [17.06.2019]
         * @returns {JSX.Element}
         */
        get: function () {
            var props = this.props;
            return (React.createElement(React.Fragment, null,
                props.title && (React.createElement(title_1.Title, null, this.t(props.title))),
                props.children && (React.createElement(layout_1.FlexLayout, { className: 'rac-dialog-body-content' }, props.children))));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "footerElement", {
        /**
         * @stable [24.03.2019]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            var props = this.props;
            return (util_1.orNull(this.closable || this.acceptable, function () { return (React.createElement(layout_1.FlexLayout, { row: true, full: false, className: 'rac-dialog-footer-actions' },
                util_1.orNull(_this.closable, function () { return (React.createElement(button_1.Button, { icon: 'close', full: true, disabled: _this.isCloseButtonDisabled(), onClick: _this.onClose }, _this.t(props.closeMessage || _this.settings.messages.dialogCancelMessage))); }),
                util_1.orNull(_this.acceptable, function () { return (React.createElement(button_1.Button, { icon: 'ok-filled', full: true, raised: true, disabled: _this.isAcceptButtonDisabled(), onClick: _this.onAccept }, _this.t(props.acceptMessage || _this.settings.messages.dialogAcceptMessage))); }))); }));
        },
        enumerable: true,
        configurable: true
    });
    return Dialog;
}(base_1.BaseComponent));
exports.Dialog = Dialog;
//# sourceMappingURL=dialog.component.js.map