/// <reference types="react" />
import { ILogger } from 'ts-smart-logger';
import { IUniversalField } from '../../../entities-definitions.interface';
import { IUniversalFieldProps } from '../../../props-definitions.interface';
import { AnyT } from '../../../definitions.interface';
import { IUniversalFieldState } from './field.interface';
import { UniversalComponent } from '../../base/universal.component';
export declare abstract class UniversalField<TProps extends IUniversalFieldProps<TKeyboardEvent, TFocusEvent, TBasicEvent>, TState extends IUniversalFieldState, TKeyboardEvent, TFocusEvent, TBasicEvent> extends UniversalComponent<TProps, TState> implements IUniversalField<TProps, TState> {
    protected static logger: ILogger;
    private static DEFAULT_CARET_BLINKING_FREQUENCY_TIMEOUT;
    private caretBlinkingTask;
    /**
     * @stable [17.06.2018]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [04.09.2018]
     */
    componentWillUnmount(): void;
    /**
     * @stable [20.08.2018]
     */
    componentDidMount(): void;
    /**
     * @stable [04.09.2018]
     * @param {TProps} prevProps
     * @param {TState} prevState
     */
    componentDidUpdate(prevProps: TProps, prevState: TState): void;
    /**
     * @stable [17.06.2018]
     */
    resetError(): void;
    /**
     * @stable [20.08.2018]
     */
    clearValue(): void;
    /**
     * @stable [27.07.2018]
     * @param {AnyT} event
     */
    onChange(event: AnyT): void;
    /**
     * @stable [07.01.2018]
     * @param {AnyT} currentRawValue
     */
    onChangeManually(currentRawValue: AnyT): void;
    /**
     * @stable [22.10.2018]
     * @returns {AnyT}
     */
    readonly value: AnyT;
    /**
     * @stable [18.06.2018]
     * @param {TKeyboardEvent} event
     */
    onKeyBackspace(event: TKeyboardEvent): void;
    /**
     * @stable [18.06.2018]
     * @param {TKeyboardEvent} event
     */
    onKeyUp(event: TKeyboardEvent): void;
    /**
     * @stable [03.09.2018]
     * @param {TKeyboardEvent} event
     */
    onKeyDown(event: TKeyboardEvent): void;
    /**
     * @stable [18.06.2018]
     * @param {TKeyboardEvent} event
     */
    onKeyEnter(event: TKeyboardEvent): void;
    /**
     * @stable [04.09.2018]
     * @param {TKeyboardEvent} event
     */
    onKeyTab(event: TKeyboardEvent): void;
    /**
     * @stable [18.06.2018]
     * @param {TKeyboardEvent} event
     */
    onKeyEscape(event: TKeyboardEvent): void;
    /**
     * @stable [18.06.2018]
     * @param {TKeyboardEvent} event
     */
    onKeyArrowDown(event: TKeyboardEvent): void;
    /**
     * @stable [18.06.2018]
     * @param {TKeyboardEvent} event
     */
    onKeyArrowUp(event: TKeyboardEvent): void;
    /**
     * @stable [17.06.2018]
     * @param {AnyT} event
     * @returns {AnyT}
     */
    abstract getRawValueFromEvent(event: AnyT): AnyT;
    /**
     * @stable [06.06.2018]
     */
    abstract setFocus(): void;
    /**
     * @stable [18.06.2018]
     * @param {boolean} usePrintf
     * @param {AnyT} args
     * @returns {string}
     */
    printfDisplayMessage(usePrintf: boolean, ...args: AnyT[]): string;
    /**
     * @stable [17.06.2018]
     * @param {AnyT} value
     * @returns {boolean}
     */
    protected isValuePresent(value?: any): boolean;
    /**
     * @stable [18.12.2018]
     * @returns {boolean}
     */
    protected isNotDefaultValuePresent(): boolean;
    /**
     * @stable [05.10.2018]
     * @returns {boolean}
     */
    protected isFieldRequired(): boolean;
    /**
     * @stable [05.10.2018]
     * @returns {boolean}
     */
    protected isFieldInvalid(): boolean;
    /**
     * @stable [17.06.2018]
     * @returns {AnyT}
     */
    protected getEmptyValue(): AnyT;
    /**
     * @stable [18.06.2018]
     * @returns {AnyT}
     */
    protected readonly definiteValue: AnyT;
    /**
     * @stable [31.07.2018]
     * @param {AnyT} value
     * @returns {string}
     */
    protected validateValueAndSetCustomValidity(value: AnyT): string;
    /**
     * @stable [31.07.2018]
     * @param {AnyT} value
     * @returns {string}
     */
    protected validateValue(value: AnyT): string;
    /**
     * @stable [03.09.2018]
     * @returns {boolean}
     */
    protected isInputValid(): boolean;
    /**
     * @stable [31.07.2018]
     * @returns {string}
     */
    protected getNativeInputValidationMessage(): string;
    /**
     * @stable [31.07.2018]
     * @param {string} error
     */
    protected setNativeInputValidity(error: string): void;
    /**
     * @stable [17.06.2018]
     * @returns {Array<string | RegExp>}
     */
    protected getFieldMask(): Array<string | RegExp>;
    /**
     * @stable [17.06.2018]
     * @returns {string}
     */
    protected getFieldPattern(): string;
    /**
     * @stable [18.06.2018]
     * @returns {AnyT}
     */
    protected readonly displayValue: AnyT;
    /**
     * @stable [07.01.2019]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    protected toDisplayValue(value: AnyT): AnyT;
    /**
     * @stable [12.02.2019]
     * @param {AnyT} value
     * @param {boolean} returnDisplayValue
     * @returns {AnyT}
     */
    protected getDecoratedValue(value: AnyT, returnDisplayValue?: boolean): AnyT;
    /**
     * @stable [07.01.2018]
     * @returns {boolean}
     */
    protected readonly hasDisplayValue: boolean;
    /**
     * @stable [07.01.2018]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    protected decorateValueBeforeDisplaying(value: AnyT): AnyT;
    /**
     * @stable [06.10.2018]
     * @returns {boolean}
     */
    protected isFieldInactive(): boolean;
    /**
     * @stable [10.06.2019]
     * @returns {boolean}
     */
    protected isFieldDisabled(): boolean;
    /**
     * @stable [06.10.2018]
     * @returns {boolean}
     */
    protected isFieldChangeable(): boolean;
    /**
     * @stable [27.01.2019]
     * @returns {boolean}
     */
    protected isFieldFocused(): boolean;
    /**
     * @stable [18.06.2019]
     * @returns {boolean}
     */
    protected isFieldVisible(): boolean;
    /**
     * @stable [11.09.2019]
     * @returns {boolean}
     */
    protected isFieldInProgress(): boolean;
    /**
     * @deprecated Use isFieldInProgress
     */
    protected inProgress(): boolean;
    /**
     * @stable [04.09.2018]
     * @param {TFocusEvent} event
     */
    protected onFocus(event: TFocusEvent): void;
    /**
     * @stable [18.06.2018]
     * @param {TFocusEvent} event
     */
    protected onBlur(event: TFocusEvent): void;
    /**
     * @stable [18.06.2018]
     * @param {TBasicEvent} event
     */
    protected onClick(event: TBasicEvent): void;
    /**
     * @stable [03.09.2018]
     * @returns {JSX.Element}
     */
    protected getInputAttachmentElement(): JSX.Element;
    /**
     * @stable [03.09.2018]
     * @returns {JSX.Element}
     */
    protected keyboardElement(): JSX.Element;
    /**
     * @stable [08.05.2019]
     */
    protected openSyntheticKeyboard(): boolean;
    /**
     * @stable [04.09.2018]
     */
    protected closeSyntheticKeyboard(): void;
    /**
     * @stable [04.09.2018]
     */
    protected onCloseKeyboard(): void;
    /**
     * @stable [03.09.2018]
     * @returns {JSX.Element}
     */
    protected getKeyboardElement(): JSX.Element;
    /**
     * @stable [13.01.2019]
     * @returns {boolean}
     */
    protected isKeyboardOpened(): boolean;
    /**
     * @stable [03.09.2018]
     * @returns {JSX.Element}
     */
    protected getErrorMessageElement(): JSX.Element;
    /**
     * @stable [03.09.2018]
     * @returns {JSX.Element}
     */
    protected getMessageElement(): JSX.Element;
    /**
     * @stable [03.09.2018]
     * @returns {string}
     */
    protected readonly error: string;
    /**
     * @stable [04.09.2018]
     */
    protected refreshCaretPosition(): void;
    /**
     * @stable [04.09.2018]
     * @returns {number}
     */
    protected getCaretPosition(): number;
    /**
     * @stable [14.01.2019]
     * @returns {boolean}
     */
    protected readonly useSyntheticCursor: boolean;
    /**
     * @stable [18.06.2018]
     * @returns {boolean}
     */
    protected abstract hasInputFocus(): boolean;
    /**
     * @stable [03.09.2018]
     */
    protected abstract removeFocus(): void;
    /**
     * @stable [22.03.2019]
     * @param {string} message
     * @param {string} className
     * @returns {JSX.Element}
     */
    protected abstract toMessageElement(message: string, className?: string): JSX.Element;
    /**
     * @stable [31.07.2018]
     * @param {AnyT} currentRawValue
     */
    private onChangeValue;
    /**
     * @stable [25.05.2019]
     * @param {any | AnyT | boolean} actualChangedValue
     */
    private submitBufferedValue;
    /**
     * @stable [31.07.2018]
     * @param {AnyT} rawValue
     */
    private validateField;
    /**
     * @stable [17.06.2018]
     * @param {AnyT} rawValue
     */
    private propsChangeForm;
    /**
     * @stable [17.06.2018]
     * @param {AnyT} rawValue
     */
    private propsOnChange;
    /**
     * @stable [04.09.2018]
     */
    private setCaretVisibility;
}
