import { IEntity, IKeyValue } from '../../../definitions.interface';
import { MultiFieldEntityT, NotMultiFieldEntityT, MultiFieldSingleValueT, IMultiFieldChangesEntity } from './multifield.interface';
import { IMultiEntity, IMultiItemEntity } from '../../../entities-definitions.interface';
/**
 * @stable [26.07.2019]
 * @param {Partial<IMultiEntity>} initial
 * @returns {IMultiEntity}
 */
export declare const multiEntityFactory: (initial: Partial<IMultiEntity>) => IMultiEntity;
/**
 * @stable [27.02.2019]
 * @param {IEntity[]} currentEntities
 * @param {number} itemsLimit
 * @returns {TItem[]}
 */
export declare const asViewedMultiItemEntities: <TItem extends IEntity = IEntity>(currentEntities: IEntity[], itemsLimit: number) => TItem[];
/**
 * @stable [15.05.2019]
 * @param {MultiFieldEntityT} entity
 * @param {boolean} sort
 * @returns {TItem[]}
 */
export declare const toActualMultiItemEntities: <TItem extends IEntity = IEntity>(entity: MultiFieldEntityT<IEntity>, sort?: boolean) => TItem[];
/**
 * @stable [22.11.2018]
 * @param {MultiFieldEntityT} entity
 * @returns {TItem[]}
 */
export declare const toActualMultiItemDeletedEntities: <TItem extends IEntity = IEntity>(entity: MultiFieldEntityT<IEntity>) => TItem[];
/**
 * @stable [18.08.2018]
 * @param {MultiFieldEntityT} entity
 * @param {Map<EntityIdT, TItem extends IEntity>} mappedSourcedItems
 * @returns {TItem[]}
 */
export declare const toActualMultiItemEditedEntities: <TItem extends IEntity = IEntity>(entity: MultiFieldEntityT<IEntity>, mappedSourcedItems?: Map<string | number, TItem>) => TItem[];
/**
 * @stable [26.12.2018]
 * @param {MultiFieldEntityT} entity
 * @returns {TItem[]}
 */
export declare const toActualMultiItemAddedEntities: <TEntity extends IEntity = IEntity>(entity: MultiFieldEntityT<IEntity>) => TEntity[];
/**
 * @stable [29.07.2019]
 * @param {MultiFieldSingleValueT} multiFieldEntity
 * @returns {EntityIdT}
 */
export declare const toLastAddedMultiItemEntityId: (multiFieldEntity: MultiFieldSingleValueT) => string | number;
/**
 * @stable [26.06.2018]
 * @param {MultiFieldEntityT} multiFieldEntity
 * @returns {EntityIdT[]}
 */
export declare const fromMultiFieldEntityToEntitiesIds: (multiFieldEntity: MultiFieldEntityT<IEntity>) => (string | number)[];
/**
 * @stable [26.06.2018]
 * @param {MultiFieldEntityT} multiFieldEntity
 * @param {(entity: TItem, index: number) => TResult} mapper
 * @returns {TResult[]}
 */
export declare function fromMultiFieldEntityToEntities<TItem extends IEntity = IEntity, TResult = IEntity>(multiFieldEntity: MultiFieldEntityT, mapper: (entity: TItem, index: number) => TResult): TResult[];
/**
 * @stable [04.07.2018]
 * @param {MultiFieldEntityT} multiFieldEntity
 * @returns {EntityIdT[]}
 */
export declare const fromMultiFieldEntityToEditedEntitiesIds: (multiFieldEntity: MultiFieldEntityT<IEntity>) => (string | number)[];
/**
 * @stable [18.08.2018]
 * @param {MultiFieldEntityT} multiFieldEntity
 * @param {(entity: TItem, index: number) => TResult} mapper
 * @returns {TResult[]}
 */
export declare function fromMultiFieldEntityToEditedEntities<TItem extends IEntity = IEntity, TResult = IEntity>(multiFieldEntity: MultiFieldEntityT, mapper: (entity: TItem, index: number) => TResult): TResult[];
/**
 * @stable [22.11.2018]
 * @param {MultiFieldEntityT} multiFieldEntity
 * @param {(entity: TItem, index: number) => TResult} mapper
 * @returns {TResult[]}
 */
export declare function fromMultiFieldEntityToDeletedEntities<TItem extends IEntity = IEntity, TResult = IEntity>(multiFieldEntity: MultiFieldEntityT, mapper: (entity: TItem, index: number) => TResult): TResult[];
/**
 * @stable [24.06.2018]
 * @param {MultiFieldEntityT | EntityIdT} value
 * @returns {number}
 */
export declare const toActualMultiItemEntitiesLength: (value: string | number | IEntity[] | IMultiEntity) => number;
/**
 * @stable [03.07.2018]
 * @param {NotMultiFieldEntityT} value
 * @returns {IEntity[]}
 */
export declare const normalizeEntities: (value: NotMultiFieldEntityT<IEntity>) => IEntity[];
/**
 * @stable [24.06.2018]
 * @param {MultiFieldEntityT | EntityIdT} value
 * @returns {boolean}
 */
export declare const isNotMultiEntity: (value: string | number | IEntity[] | IMultiEntity) => boolean;
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {(value: IMultiEntity) => IMultiItemEntity[]} converter
 * @param {IEntity[]} defaultValue
 * @returns {IMultiItemEntity[] | IEntity[]}
 */
export declare const extractMultiItemEntities: (value: MultiFieldEntityT<IEntity>, converter: (value: IMultiEntity) => IMultiItemEntity[], defaultValue: IEntity[]) => IEntity[] | IMultiItemEntity[];
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {IMultiItemEntity[]} defaultValue
 * @returns {IMultiItemEntity[]}
 */
export declare const extractMultiEditItemEntities: (value: MultiFieldEntityT<IEntity>, defaultValue?: IMultiItemEntity[]) => IMultiItemEntity[];
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {IMultiItemEntity[]} defaultValue
 * @returns {IMultiItemEntity[]}
 */
export declare const extractMultiRemoveItemEntities: (value: MultiFieldEntityT<IEntity>, defaultValue?: IMultiItemEntity[]) => IMultiItemEntity[];
/**
 * @stable [02.07.2018]
 * @param {MultiFieldEntityT} value
 * @param {IMultiItemEntity[]} defaultValue
 * @returns {IEntity[]}
 */
export declare const extractMultiAddItemEntities: (value: MultiFieldEntityT<IEntity>, defaultValue?: IMultiItemEntity[]) => IEntity[];
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {IEntity[]} defaultValue
 * @returns {IEntity[]}
 */
export declare const extractMultiSourceItemEntities: (value: MultiFieldEntityT<IEntity>, defaultValue?: IEntity[]) => IEntity[];
/**
 * @stable [02.07.2018]
 * @param {IEntity | IMultiItemEntity} entity
 * @returns {IEntity}
 */
export declare const fromMultiItemEntityToEntity: (entity: IEntity | IMultiItemEntity) => IEntity;
/**
 * @stable [02.07.2018]
 * @param {string} name
 * @param {AnyT} value
 * @param {IEntity} rawData
 * @param {boolean} newEntity
 * @returns {IMultiItemEntity}
 */
export declare const buildMultiEntity: (name: string, value: any, rawData: IEntity, newEntity?: boolean) => IMultiItemEntity;
/**
 * @stable [23.06.2018]
 * @param {string} fieldName
 * @param {MultiFieldEntityT} multiFieldValue
 * @param {(itm: IMultiItemEntity) => boolean} predicate
 * @param {(itm: IMultiItemEntity) => AnyT} nextFieldValueFn
 * @returns {IMultiItemEntity}
 */
export declare const buildMultiEditItemEntityPayload: <TEntity extends IEntity = IEntity>(fieldName: string, multiFieldValue: MultiFieldEntityT<IEntity>, predicate: (itm: IMultiItemEntity) => boolean, nextFieldValueFn: (multiItemEntity: IMultiItemEntity, entity: TEntity) => any) => IMultiItemEntity;
/**
 * @stable [04.07.2018]
 * @param {IMultiItemEntity[]} multiItemEntities
 * @returns {IKeyValue}
 */
export declare const fromMultiItemEntitiesToFieldsChanges: (multiItemEntities: IMultiItemEntity[]) => IKeyValue;
/**
 * @stable [11.08.2018]
 * @param {IMultiItemEntity} first
 * @param {IMultiItemEntity} second
 * @returns {boolean}
 */
export declare const isSameEntityByIdAndChangedFieldName: (first: IMultiItemEntity, second: IMultiItemEntity) => boolean;
/**
 * @stable [11.08.2018]
 * @param {IMultiItemEntity} item
 * @param {IEntity[]} addValue
 * @param {IMultiItemEntity[]} removeValue
 * @param {IMultiItemEntity[]} editValue
 * @param {IEntity[]} originalValue
 * @returns {IMultiFieldChangesEntity}
 */
export declare const toMultiFieldChangesEntityOnEdit: (item: IMultiItemEntity, addValue: IEntity[], removeValue: IMultiItemEntity[], editValue: IMultiItemEntity[], originalValue: IEntity[]) => IMultiFieldChangesEntity;
/**
 * @stable [18.08.2018]
 * @param {IMultiItemEntity} item
 * @param {IEntity[]} addValue
 * @param {IMultiItemEntity[]} removeValue
 * @param {IMultiItemEntity[]} editValue
 * @param {IEntity[]} originalValue
 * @returns {IMultiFieldChangesEntity}
 */
export declare const toMultiFieldChangesEntityOnDelete: (item: IMultiItemEntity, addValue: IEntity[], removeValue: IMultiItemEntity[], editValue: IMultiItemEntity[], originalValue: IEntity[]) => IMultiFieldChangesEntity;
/**
 * @stable [07.03.2019]
 * @param {MultiFieldEntityT<TEntity extends IEntity>} multiEntity
 * @param {MultiFieldEntityT<TEntity extends IEntity>} updatedSource
 * @param {(entity: TEntity) => boolean} addFilter
 * @param {(entity: TEntity) => boolean} editFilter
 * @param {(entity: TEntity) => boolean} removeFilter
 * @returns {IMultiEntity}
 */
export declare const toFilteredMultiEntity: <TEntity extends IEntity>(multiEntity: MultiFieldEntityT<TEntity>, updatedSource: MultiFieldEntityT<TEntity>, addFilter?: (entity: TEntity) => boolean, editFilter?: (entity: TEntity) => boolean, removeFilter?: (entity: TEntity) => boolean) => IMultiEntity;
