import { IEffectsAction } from 'redux-effects-promise';
import { AnyT, EntityIdT, IDataWrapper, IEntity, IRemovedEntityWrapper, ISelectedEntityWrapper } from '../../definitions.interface';
import { IPagedEntity } from '../../definition';
import { IModifyEntityPayloadWrapper } from '../../api';
export declare class ListActionBuilder {
    static buildChangeSortDirectionActionType(section: string): string;
    static buildChangeActionType(section: string): string;
    static buildFirstPageActionType(section: string): string;
    static buildLastPageActionType(section: string): string;
    static buildPreviousPageActionType(section: string): string;
    static buildNextPageActionType(section: string): string;
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildLoadActionType(section: string): string;
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildCancelLoadActionType(section: string): string;
    /**
     * @stable [03.06.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildLazyLoadActionType(section: string): string;
    /**
     * @stable [03.06.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildLazyLoadDoneActionType(section: string): string;
    static buildUnTouchActionType(section: string): string;
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildLoadDoneActionType(section: string): string;
    /**
     * @stable [31.08.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildLoadErrorActionType(section: string): string;
    /**
     * @stable [04.06.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildLazyLoadErrorActionType(section: string): string;
    /**
     * @stable [07.12.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildSelectActionType(section: string): string;
    /**
     * @stable [07.12.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildSelectErrorActionType(section: string): string;
    static buildInsertActionType(section: string): string;
    /**
     * @stable [17.05.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildRemoveActionType(section: string): string;
    /**
     * @stable [22.01.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildMergeActionType(section: string): string;
    static buildUpdateActionType(section: string): string;
    /**
     * @stable [07.12.2018]
     * @param {string} section
     * @returns {string}
     */
    static buildCreateActionType(section: string): string;
    static buildDeselectActionType(section: string): string;
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildDestroyActionType(section: string): string;
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {string}
     */
    static buildResetActionType(section: string): string;
    /**
     * @stable [21.04.2019]
     * @param {string} section
     * @param {TData} data
     * @returns {IEffectsAction}
     */
    static buildLazyLoadDoneAction<TData>(section: string, data: TData): IEffectsAction;
    /**
     * @stable [08.12.2018]
     * @param {string} section
     * @param {ISelectedEntityWrapper} payload
     * @returns {IEffectsAction}
     */
    static buildSelectAction(section: string, payload: ISelectedEntityWrapper): IEffectsAction;
    /**
     * @stable [15.03.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildCreateAction(section: string): IEffectsAction;
    /**
     * @stable [08.12.2018]
     * @param {string} section
     * @param {ISelectedEntityWrapper} payload
     * @returns {IEffectsAction}
     */
    static buildSelectSimpleAction(section: string, payload: ISelectedEntityWrapper): IEffectsAction;
    /**
     * @stable [20.01.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildCreateSimpleAction(section: string): IEffectsAction;
    /**
     * @stable [03.06.2018]
     * @param {string} section
     * @param {ISelectedEntityWrapper} payload
     * @returns {IEffectsAction}
     */
    static buildLazyLoadAction(section: string, payload: ISelectedEntityWrapper): IEffectsAction;
    static buildDeselectAction(section: string): IEffectsAction;
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildDestroyAction(section: string): IEffectsAction;
    /**
     * @stable [19.03.2019]
     * @param {string} section
     * @returns {IEffectsAction}
     */
    static buildResetAction(section: string): IEffectsAction;
    static buildInsertAction(section: string, data?: IModifyEntityPayloadWrapper): IEffectsAction;
    /**
     * @stable [22.01.2019]
     * @param {string} section
     * @param {IModifyEntityPayloadWrapper} data
     * @returns {IEffectsAction}
     */
    static buildMergeAction(section: string, data?: IModifyEntityPayloadWrapper): IEffectsAction;
    /**
     * @stable [17.05.2018]
     * @param {string} section
     * @param {IRemovedEntityWrapper} data
     * @returns {IEffectsAction}
     */
    static buildRemoveAction(section: string, data: IRemovedEntityWrapper): IEffectsAction;
    static buildUpdateAction(section: string, data?: IModifyEntityPayloadWrapper): IEffectsAction;
    /**
     * @stable [13.05.2019]
     * @param {string} section
     * @param {EntityIdT} id
     * @param {TChanges} changes
     * @returns {IEffectsAction}
     */
    static buildMergeItemAction<TChanges = IEntity>(section: string, id: EntityIdT, changes: TChanges): IEffectsAction;
    /**
     * @stable [06.06.2019]
     * @param {string} section
     * @param {EntityIdT} id
     * @param {TChanges} changes
     * @returns {IEffectsAction}
     */
    static buildInsertItemAction<TChanges = IEntity>(section: string, id: EntityIdT, changes: TChanges): IEffectsAction;
    /**
     * @stable [13.05.2019]
     * @param {string} section
     * @param {EntityIdT} id
     * @param {TChanges} changes
     * @returns {IEffectsAction}
     */
    static buildUpdateItemAction<TChanges = IEntity>(section: string, id: EntityIdT, changes: TChanges): IEffectsAction;
    static buildLoadAction(section: string, data?: AnyT): IEffectsAction;
    /**
     * @stable [13.05.2019]
     * @param {string} section
     * @param {IDataWrapper<AnyT> & IPagedEntity} data
     * @returns {IEffectsAction}
     */
    static buildLoadDoneAction(section: string, data?: IDataWrapper<AnyT> & IPagedEntity): IEffectsAction;
    static buildNextPageAction(section: string, data?: AnyT): IEffectsAction;
    static buildPreviousPageAction(section: string, data?: AnyT): IEffectsAction;
    static buildFirstPageAction(section: string, data?: AnyT): IEffectsAction;
    static buildLastPageAction(section: string, data?: AnyT): IEffectsAction;
}
