"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var di_1 = require("../../di");
var util_1 = require("../../util");
var StickyHeaderPlugin = /** @class */ (function () {
    /**
     * @stable [13.12.2018]
     * @param {IUniversalScrollableComponent} component
     */
    function StickyHeaderPlugin(component) {
        var _this = this;
        this.component = component;
        this.delayedTask = new util_1.DelayedTask(this.onDelayedTask.bind(this), 400);
        component.onScroll = util_1.sequence(component.onScroll, function () {
            if (_this.stickyElementInitialProperties) {
                util_1.setStickyElementProperties(__assign({}, _this.stickyElementInitialProperties, { initial: true }));
                _this.delayedTask.start();
            }
        });
    }
    /**
     * @stable [13.12.2018]
     */
    StickyHeaderPlugin.prototype.componentDidMount = function () {
        this.stickyElementInitialProperties = this.getStickyElementInitialProperties();
        if (!R.isNil(this.stickyElementInitialProperties)) {
            this.selfElementHeight = this.selfHeight;
        }
    };
    /**
     * @stable [13.12.2018]
     */
    StickyHeaderPlugin.prototype.componentWillUnmount = function () {
        this.stickyElementInitialProperties = null;
        this.delayedTask.stop();
    };
    /**
     * @stable [13.12.2018]
     */
    StickyHeaderPlugin.prototype.componentDidUpdate = function () {
        this.doUpdate();
    };
    Object.defineProperty(StickyHeaderPlugin.prototype, "selfHeight", {
        /**
         * @stable [13.12.2018]
         * @returns {number}
         */
        get: function () {
            return this.domAccessor.getHeight(this.component.getSelf());
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [13.12.2018]
     * @returns {IStickyElementPayloadEntity}
     */
    StickyHeaderPlugin.prototype.getStickyElementInitialProperties = function () {
        return util_1.getStickyElementInitialProperties(this.domAccessor.toJqEl(this.component.getSelf()));
    };
    /**
     * @stable [20.12.2018]
     */
    StickyHeaderPlugin.prototype.doUpdate = function () {
        var selfHeight = this.selfHeight;
        var stickyElementInitialProperties0 = this.getStickyElementInitialProperties();
        var hasStickyElementChanged = !R.isNil(stickyElementInitialProperties0)
            && !R.isNil(this.stickyElementInitialProperties)
            && stickyElementInitialProperties0.jqStickyEl.get()[0] !== this.stickyElementInitialProperties.jqStickyEl.get()[0];
        /**
         * Only this way we can detect the DOM changes
         */
        if (selfHeight !== this.selfElementHeight || hasStickyElementChanged) {
            var stickyElementInitialProperties = this.getStickyElementInitialProperties();
            if (!R.isNil(stickyElementInitialProperties)) {
                this.selfElementHeight = selfHeight;
                this.stickyElementInitialProperties = stickyElementInitialProperties;
            }
        }
    };
    StickyHeaderPlugin.prototype.onDelayedTask = function () {
        util_1.setStickyElementProperties(this.stickyElementInitialProperties);
    };
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.DomAccessor),
        __metadata("design:type", Object)
    ], StickyHeaderPlugin.prototype, "domAccessor", void 0);
    return StickyHeaderPlugin;
}());
exports.StickyHeaderPlugin = StickyHeaderPlugin;
//# sourceMappingURL=sticky-header.plugin.js.map