"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var di_module_1 = require("./di.module");
exports.cachedServices = new Map();
/**
 * @stable [26.04.2018]
 * @param {interfaces.ServiceIdentifier<T>} serviceIdentifier
 * @returns {any}
 */
exports.staticInjector = function (serviceIdentifier) {
    // Two-level cache because of a low performance
    var instance = exports.cachedServices.get(serviceIdentifier);
    if (exports.cachedServices.has(serviceIdentifier)) {
        return instance; // Null or instance
    }
    if (di_module_1.appContainer.isBound(serviceIdentifier)) {
        exports.cachedServices.set(serviceIdentifier, instance = di_module_1.appContainer.get(serviceIdentifier));
    }
    else {
        exports.cachedServices.set(serviceIdentifier, instance = null);
    }
    return instance;
};
/**
 * @stable [26.04.2018]
 * @param target
 * @returns {(target: any) => any}
 */
exports.provideInSingleton = function (target) { return di_module_1.provideInSingletonDecorator(target)
    .inSingletonScope()
    .done(true); };
/**
 * @stable [16.09.2019]
 * @param {interfaces.ServiceIdentifier<T> | {new(...args: AnyT[]): T}} contract
 * @param {{new(...args: AnyT[]): T}} implementation
 * @returns {interfaces.BindingWhenOnSyntax<any>}
 */
exports.bindInSingleton = function (contract, implementation) {
    return (di_module_1.appContainer.isBound(contract)
        ? di_module_1.appContainer.rebind(contract)
        : di_module_1.appContainer.bind(contract)).to(implementation || contract).inSingletonScope();
};
//# sourceMappingURL=di.support.js.map