"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ts_smart_logger_1 = require("ts-smart-logger");
var P = require("platform");
var filter_1 = require("../util/filter");
var route_1 = require("../util/route");
var definedLocation = typeof location === 'undefined'
    ? { origin: '', protocol: 'http', host: 'localhost', port: '80', href: '', pathname: '', assign: function (url) { return null; } }
    : location;
var definedWindow = typeof window === 'undefined' ? {} : window;
var definedDocument = typeof document === 'undefined' ? { baseURI: '', body: null } : document;
var definedLocalStorage = typeof localStorage === 'undefined' ? { getItem: function (item) { return null; } } : localStorage;
var origin = definedLocation.origin || [definedLocation.protocol, definedLocation.host].join('//');
var BASE_PATH = (definedDocument.baseURI || definedLocation.href).replace(origin, '');
var RN_PLATFORM_NAME = Reflect.get(definedWindow, '$$RAC-RN_PLATFORM_NAME');
var SAFARI_PLATFORM = P.name === 'Safari';
/**/
var ANDROID_PLATFORM = P.os.family === 'Android';
var IOS_PLATFORM = P.os.family === 'iOS';
var MAC_PLATFORM = P.os.family === 'OS X';
var WINDOWS_PHONE_PLATFORM = P.os.family === 'Windows Phone';
/**/
exports.ENV = filter_1.defValuesFilter({
    document: definedDocument,
    appVersion: process.env.APP_VERSION || '0.0.1',
    appProfile: process.env.APP_PROFILE || 'DEFAULT',
    appNamespace: process.env.APP_NAMESPACE,
    prodMode: process.env.NODE_ENV === 'production',
    stageMode: process.env.NODE_ENV === 'stage',
    devModeEnabled: !!definedLocalStorage.getItem('$$RAC-DEV_MODE'),
    googleKey: process.env.GOOGLE_KEY,
    googleMapsKey: process.env.GOOGLE_MAPS_KEY,
    rnPlatformName: RN_PLATFORM_NAME,
    rnPlatform: !!RN_PLATFORM_NAME,
    /**/
    androidPlatform: ANDROID_PLATFORM,
    iosPlatform: IOS_PLATFORM,
    macPlatform: MAC_PLATFORM,
    windowsPhonePlatform: WINDOWS_PHONE_PLATFORM,
    mobilePlatform: ANDROID_PLATFORM || IOS_PLATFORM || WINDOWS_PHONE_PLATFORM,
    /**/
    host: definedLocation.host,
    basePath: BASE_PATH,
    normalizedBasePath: BASE_PATH.replace(/\//g, ''),
    port: definedLocation.port || '80',
    platformName: P.name,
    platformOs: P.os,
    safariPlatform: SAFARI_PLATFORM,
    passwordInputPlaceholder: SAFARI_PLATFORM && IOS_PLATFORM ? '●' : '•',
    documentBody: definedDocument.body,
    localModeEnabled: location.hostname === 'localhost',
    appPath: function () { return route_1.buildNormalizedPath((definedLocation.pathname + "/").replace(BASE_PATH, '/')); },
    buildAppPath: function (path) { return route_1.buildNormalizedPath(BASE_PATH + "/" + path + "/"); },
    setVariable: function (name, scope) { return Reflect.set(definedWindow, name, scope); },
});
ts_smart_logger_1.LoggerFactory.makeLogger('env.interface').debug("[$environment] " + JSON.stringify(exports.ENV));
//# sourceMappingURL=env.interface.js.map