"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var base_storage_service_1 = require("../base-storage.service");
var util_1 = require("../../util");
var definition_1 = require("../../definition");
var DefaultStorage = /** @class */ (function (_super) {
    __extends(DefaultStorage, _super);
    /**
     * @stable [28.07.2019]
     * @param {string} prefix
     * @param {() => ISettings} settingsProvider
     * @param {StorageTypesEnum} storageType
     */
    function DefaultStorage(prefix, settingsProvider, storageType) {
        var _this = _super.call(this, prefix) || this;
        _this.settingsProvider = settingsProvider;
        _this.storageType = storageType;
        return _this;
    }
    /**
     * @stable [28.07.2019]
     * @param {string} key
     * @param {AnyT} value
     * @returns {Promise<boolean>}
     */
    DefaultStorage.prototype.set = function (key, value) {
        this.storage.setItem(this.toKey(key), JSON.stringify(value));
        return Promise.resolve(true);
    };
    /**
     * @stable [28.07.2019]
     * @param {string} key
     * @returns {Promise<AnyT>}
     */
    DefaultStorage.prototype.get = function (key) {
        return Promise.resolve(util_1.ifNotNilThanValue(this.storage.getItem(this.toKey(key)), function (v) { return JSON.parse(v); }));
    };
    /**
     * @stable [28.07.2019]
     * @param {string} key
     * @param {boolean} noPrefix
     * @returns {Promise<boolean>}
     */
    DefaultStorage.prototype.remove = function (key, noPrefix) {
        this.storage.removeItem(noPrefix ? key : this.toKey(key));
        return Promise.resolve();
    };
    /**
     * @stable [28.07.2019]
     * @param {(key: string, value: AnyT) => void} callback
     */
    DefaultStorage.prototype.each = function (callback) {
        var storage = this.storage;
        for (var i = 0; i < storage.length; i++) {
            var key = storage.key(i);
            callback(this.toKey(key), storage.getItem(key));
        }
    };
    Object.defineProperty(DefaultStorage.prototype, "storage", {
        /**
         * @stable [28.07.2019]
         * @returns {Storage}
         */
        get: function () {
            var settings = this.settingsProvider();
            switch (util_1.nvl(this.storageType, settings && settings.persistenceStorage)) {
                case definition_1.StorageTypesEnum.SESSION:
                    return sessionStorage;
                default:
                    return localStorage;
            }
        },
        enumerable: true,
        configurable: true
    });
    return DefaultStorage;
}(base_storage_service_1.BaseStorage));
exports.DefaultStorage = DefaultStorage;
//# sourceMappingURL=default-storage.service.js.map