"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var ts_smart_logger_1 = require("ts-smart-logger");
var util_1 = require("../../util");
var router_1 = require("../../router");
var action_builder_1 = require("../../component/action.builder");
var application_interface_1 = require("../../component/application/application.interface");
var di_1 = require("../../di");
var notification_1 = require("../../notification");
var logger = ts_smart_logger_1.LoggerFactory.makeLogger('succeed-form.middleware');
/**
 * @stable [22.08.2018]
 * @param {ISucceedRelatedFormMiddlewareConfig<TEntity extends IEntity, TRelatedEntity extends IEntity>} config
 * @returns {IEffectsAction[]}
 */
exports.makeSucceedRelatedFormMiddleware = function (config) {
    var formSection = config.formSection;
    var apiEntity = config.action.data;
    var parentEntity = config.getEntity(config.state);
    var relatedEntities = apiEntity.newEntity
        ? (config.getRelatedEntities(parentEntity) || []).concat(config.relatedEntity)
        : (config.getRelatedEntities(parentEntity) || []).map(function (anotherEntity) { return anotherEntity.id === config.relatedEntity.id ? config.relatedEntity : anotherEntity; });
    var changes = config.makeRelatedChanges(relatedEntities);
    var payloadWrapper = { payload: { id: parentEntity.id, changes: changes } };
    return util_1.ifNotNilThanValue(config.listSection, function (listSection) { return ([
        action_builder_1.ListActionBuilder.buildUpdateAction(listSection, payloadWrapper),
        config.navigateBack !== false
            ? router_1.RouterActionBuilder.buildNavigateBackAction()
            : action_builder_1.FormActionBuilder.buildSubmitDoneAction(formSection)
    ]); }, []).concat([
        notification_1.NotificationActionBuilder.buildInfoAction(di_1.staticInjector(di_1.DI_TYPES.Translate)(config.saveMessage || di_1.staticInjector(di_1.DI_TYPES.Settings).messages.dataSaved))
    ]);
};
/**
 * @stable [07.07.2018]
 * @param {ISucceedFormMiddlewareConfig<TEntity extends IEntity>} config
 * @returns {IEffectsAction[]}
 */
exports.makeSucceedFormMiddleware = function (config) {
    var listSection = config.listSection, action = config.action, canComeBack = config.canComeBack, canUpdate = config.canUpdate, saveMessage = config.saveMessage;
    var apiEntity = action.initialData;
    var connectorConfig = application_interface_1.APPLICATION_SECTIONS.get(listSection);
    var dynamicListRoute = util_1.orNull(connectorConfig, function () { return connectorConfig.routeConfiguration.path; });
    if (!dynamicListRoute) {
        logger.warn("[$makeSucceedFormMiddleware] The list route is empty for the section " + listSection);
    }
    var isUpdateNeeded = R.isNil(canUpdate) || (util_1.isFn(canUpdate) ? canUpdate(apiEntity, action) : canUpdate);
    var payloadWrapper = isUpdateNeeded
        ? di_1.staticInjector(di_1.DI_TYPES.ModifyEntityPayloadFactory)
            .makeInstance(action)
        : null;
    return (isUpdateNeeded
        ? [action_builder_1.ListActionBuilder.buildMergeAction(listSection, payloadWrapper)]
        : []).concat(R.isNil(canComeBack) || (util_1.isFn(canComeBack) ? canComeBack(apiEntity, action) : canComeBack)
        ? router_1.RouterActionBuilder.buildReplaceAction(dynamicListRoute)
        : []).concat(notification_1.NotificationActionBuilder.buildInfoAction(di_1.staticInjector(di_1.DI_TYPES.Translate)(saveMessage || di_1.staticInjector(di_1.DI_TYPES.Settings).messages.dataSaved)));
};
//# sourceMappingURL=succeed-form.middleware.js.map