"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var inversify_1 = require("inversify");
var R = require("ramda");
var util_1 = require("../util");
var definitions_interface_1 = require("../definitions.interface");
var util_2 = require("../util");
var di_1 = require("../di");
var BaseTransport = /** @class */ (function () {
    function BaseTransport() {
        var _this = this;
        /**
         * @stable [29.08.2019]
         * @param {StringNumberT} value
         * @param {(value: number) => number} converter
         * @returns {number}
         */
        this.prepareNumberValue = function (value, converter) {
            return _this.nc.numberParameter(value, converter);
        };
        /**
         * @stable [10.08.2019]
         * @param {AnyT} value
         * @returns {AnyT}
         */
        this.prepareStringValue = function (value) {
            return util_1.ifNotNilThanValue(value, function () {
                var resultValue = value;
                if (util_2.isString(value)) {
                    resultValue = value.trim();
                }
                return util_1.orNull(!R.isEmpty(resultValue), function () { return resultValue; });
            }, definitions_interface_1.UNDEF_SYMBOL);
        };
    }
    /**
     * @stable [25.07.2019]
     * @param {string} value
     * @returns {string}
     */
    BaseTransport.prototype.preparePhoneValue = function (value) {
        return util_1.orUndef(!R.isNil(value), function () { return value.replace(/\D/g, ''); });
    };
    /**
     * @stable [31.08.2019]
     * @param {ITransportRequestEntity} params
     */
    BaseTransport.prototype.downloadFile = function (params) {
        var requestParams = this.transport.makeRequestData(params);
        util_1.downloadFileAsBlobUrl(util_1.join([this.settings.downloadUrl, util_1.buildEncodedURI(requestParams)]));
    };
    /**
     * @stable [26.02.2019]
     * @param {IEditableApiEntity<TEntity extends IEntity>} entity
     * @returns {Promise<TEntity extends IEntity>}
     */
    BaseTransport.prototype.doSaveEntity = function (entity) {
        var apiEntity = entity.apiEntity;
        return this.transport.request({
            params: __assign({}, apiEntity.changes, util_1.defValuesFilter(entity.extraParams), util_1.defValuesFilter({ id: apiEntity.entityId })),
            name: apiEntity.newEntity ? entity.addApi : entity.editApi,
            operation: entity.operation,
        });
    };
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Environment),
        __metadata("design:type", Object)
    ], BaseTransport.prototype, "environment", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.NumberConverter),
        __metadata("design:type", Object)
    ], BaseTransport.prototype, "nc", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Settings),
        __metadata("design:type", Object)
    ], BaseTransport.prototype, "settings", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Transport),
        __metadata("design:type", Object)
    ], BaseTransport.prototype, "transport", void 0);
    BaseTransport = __decorate([
        inversify_1.injectable()
    ], BaseTransport);
    return BaseTransport;
}());
exports.BaseTransport = BaseTransport;
//# sourceMappingURL=base.transport.js.map