import { IDataWrapper, AnyT } from '../../../definitions.interface';
import { ITransportRequestEntity, ITransportResponseFactory, ITransportResponseFactoryEntity } from '../../../definition';
export declare class TransportResponseFactory implements ITransportResponseFactory {
    /**
     * This is a default error response handler. The core uses Axios by default therefore here we gets a response from this one.
     *
     * @stable [01.02.2019]
     * @param {TransportResponseFactoryPayloadT} payloadEntity
     * @returns {ITransportResponseFactoryEntity}
     */
    makeErrorResponse(payloadEntity: {
        response?: any;
        message?: any;
    }): ITransportResponseFactoryEntity;
    /**
     * This is a default response handler. The core uses Axios by default therefore here we gets a response from this one.
     *
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} req
     * @param {IDataWrapper} payloadEntity
     * @returns {ITransportResponseFactoryEntity}
     */
    makeResponse(req: ITransportRequestEntity, payloadEntity: IDataWrapper<AnyT>): ITransportResponseFactoryEntity;
    /**
     * @stable [02.02.2019]
     * @param {AnyT} data
     * @returns {AnyT}
     */
    protected readResponseData<TData>(data: AnyT): AnyT;
    /**
     * @stable [04.02.2019]
     * @param {AnyT} data
     * @returns {ITransportResponseFactoryEntity}
     */
    protected readResponseErrorData<TData>(data: AnyT): ITransportResponseFactoryEntity;
}
