"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var nvl_1 = require("./nvl");
var cond_1 = require("./cond");
var filter_1 = require("./filter");
/**
 * @stable [16.12.2018]
 * @param {number} length
 * @returns {AnyT[]}
 */
exports.generateArray = function (length) { return Array.apply(null, { length: length }); };
/**
 * @stable [19.11.2018]
 * @param {number[]} array
 * @returns {number}
 */
exports.arrayMinValue = function (array) { return R.reduce(R.min, Infinity, array); };
/**
 * @stable [22.11.2018]
 * @param {number[]} array
 * @returns {number}
 */
exports.arrayNextMinNegativeValue = function (array) { return Math.min(Number(exports.arrayMinValue(array)), 0) - 1; };
/**
 * @stable [19.12.2018]
 * @param {TValue[]} array
 * @returns {boolean}
 */
exports.isArrayNotEmpty = function (array) { return Array.isArray(array) && !R.isEmpty(array); };
/**
 * @stable [28.01.2019]
 * @param {TValue[]} array
 * @param {number} limit
 * @returns {TValue[]}
 */
exports.subArray = function (array, limit) {
    return cond_1.ifNotNilThanValue(array, function () { return array.slice(0, Math.min(array.length, nvl_1.nvl(limit, array.length))); });
};
/**
 * @stable [26.07.2019]
 * @param {TValue[]} array
 * @param {TValue} initialItem
 * @param {(previousItem: TValue, initialItem: TValue) => TValue} mergedItemFactory
 * @param {(itm1: TValue, itm2: TValue) => boolean} predicate
 * @returns {TValue[]}
 */
exports.mergeArrayItem = function (array, initialItem, mergedItemFactory, predicate) {
    var array0 = array || [];
    var replacedItem = array0.find(function (itm) { return predicate(itm, initialItem); });
    var hasEntity = !R.isNil(replacedItem);
    return array0.concat((hasEntity ? [] : [initialItem])).map(function (itm) { return predicate(itm, initialItem)
        ? Object.assign({}, itm, mergedItemFactory(itm))
        : itm; });
};
/**
 * @stable [31.08.2019]
 * @param {AnyT} values
 * @returns {boolean}
 */
exports.areArrayValuesNotNil = function () {
    var values = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        values[_i] = arguments[_i];
    }
    return cond_1.ifNotNilThanValue(values, function () { return filter_1.notNilValuesArrayFilter.apply(void 0, values).length === values.length; }, false);
};
//# sourceMappingURL=array.js.map