"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var util_1 = require("../util");
var calc_1 = require("./calc");
/**
 * @stable [25.10.2018]
 * @param {AnyT} condition
 * @param {string | (() => string)} result
 * @returns {string}
 */
exports.orEmpty = function (condition, result) { return condition ? calc_1.calc(result) : ''; };
function orNull(condition, result) {
    return condition ? (util_1.isFn(result) ? result() : result) : null;
}
exports.orNull = orNull;
function orUndef(condition, result) {
    return condition ? (util_1.isFn(result) ? result() : result) : undefined;
}
exports.orUndef = orUndef;
/**
 * @deprecated
 */
function orDefault(cond, result1, result2) {
    return cond
        ? (util_1.isFn(result1) ? result1() : result1)
        : (util_1.isFn(result2) ? result2() : result2);
}
exports.orDefault = orDefault;
/**
 * @stable [10.08.2019]
 * @param {TValue} value
 * @param {(value: TValue) => TResult} callback
 * @param {any} defaultValue
 * @returns {TResult}
 */
exports.ifNotNilThanValue = function (value, callback, defaultValue) {
    if (defaultValue === void 0) { defaultValue = null; }
    return !R.isNil(value)
        ? callback(value)
        : (defaultValue === definitions_interface_1.UNDEF_SYMBOL ? definitions_interface_1.UNDEF : defaultValue);
};
/**
 * @stable [30.07.2019]
 * @param {TValue} value
 * @param {(value: TValue) => TResult} callback
 * @param {any} defaultValue
 * @returns {TResult}
 */
exports.ifNilThanValue = function (value, callback, defaultValue) {
    if (defaultValue === void 0) { defaultValue = null; }
    return R.isNil(value) ? callback(value) : defaultValue;
};
/**
 * @stable [16.09.2019]
 * @param {TValue} value
 * @param {(value: TValue) => TResult} callback
 * @param {any} defaultValue
 * @returns {TResult}
 */
exports.ifNotEmptyThanValue = function (value, callback, defaultValue) {
    if (defaultValue === void 0) { defaultValue = null; }
    return !R.isNil(value) && !R.isEmpty(value)
        ? callback(value)
        : (defaultValue === definitions_interface_1.UNDEF_SYMBOL ? definitions_interface_1.UNDEF : defaultValue);
};
/**
 * @stable [15.09.2019]
 * @param {boolean} value
 * @param {(value: boolean) => TResult} callback
 * @param {any} defaultValue
 * @returns {TResult}
 */
exports.ifNotFalseThanValue = function (value, callback, defaultValue) {
    if (defaultValue === void 0) { defaultValue = null; }
    return value !== false
        ? callback(value)
        : (defaultValue === definitions_interface_1.UNDEF_SYMBOL ? definitions_interface_1.UNDEF : defaultValue);
};
/**
 * @stable [29.03.2019]
 * @param {boolean} value
 * @param {(value: boolean) => TResult} callback
 * @param {any} defaultValue
 * @returns {TResult}
 */
exports.ifNotTrueThanValue = function (value, callback, defaultValue) {
    if (defaultValue === void 0) { defaultValue = null; }
    return value !== true ? callback(value) : defaultValue;
};
/**
 * @stable [26.06.2019]
 * @param {StringNumberT} value
 * @returns {StringNumberT}
 */
exports.ifEmptyThanNull = function (value) { return value === ''
    ? null
    : value; };
//# sourceMappingURL=cond.js.map