"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var validator_1 = require("./validator");
var cond_1 = require("./cond");
/**
 * @stable [30.01.2019]
 * @param {Record<string, ValidatorRuleEnum[]>} payloads
 * @param {IEditableEntity<TEntity extends IEntity>} editableEntity
 * @param {boolean} canSaveEmptyChanges
 * @returns {boolean}
 */
exports.canSubmitEditableEntity = function (payloads, editableEntity, canSaveEmptyChanges) {
    if (canSaveEmptyChanges === void 0) { canSaveEmptyChanges = false; }
    return !editableEntity.progress
        && validator_1.validate(payloads, editableEntity.changes).valid
        && (canSaveEmptyChanges || !R.isEmpty(editableEntity.changes));
};
/**
 * @stable [30.01.2019]
 * @param {IEntityFormEntity<TEntity extends IEntity>} entity
 * @param {Record<string, ValidatorRuleEnum[]>} editRules
 * @param {Record<string, ValidatorRuleEnum[]>} createRules
 * @returns {boolean}
 */
exports.canSubmitEntityFormEntity = function (entity, editRules, createRules) {
    return exports.canSubmitEditableEntity(exports.doesExtendedEntityExist(entity) ? editRules : createRules || editRules, entity.form);
};
/**
 * @stable [30.01.2019]
 * @param {IEditableEntity<TEntity extends IEntity>} editableEntity
 * @returns {boolean}
 */
exports.isEditableEntityBusy = function (editableEntity) {
    return editableEntity.progress === true;
};
/**
 * @stable [30.01.2019]
 * @param {IEntityFormEntity<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isEntityFormEntityBusy = function (entity) {
    return exports.isEditableEntityBusy(entity.form);
};
/**
 * @stable [30.01.2019]
 * @param {IExtendedEntity<TEntity extends IEntity>} entityWrapper
 * @returns {boolean}
 */
exports.isNewExtendedEntity = function (entityWrapper) {
    return entityWrapper.newEntity === true;
};
/**
 * @stable [30.01.2019]
 * @param {IExtendedEntity<TEntity extends IEntity>} entityWrapper
 * @returns {boolean}
 */
exports.doesExtendedEntityExist = function (entityWrapper) {
    return !R.isNil(entityWrapper) && !exports.isNewExtendedEntity(entityWrapper);
};
/**
 * @stable [30.08.2019]
 * @param {TEntity} entity
 * @returns {string}
 */
exports.entityAsFileName = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return "" + entity.id + cond_1.ifNotNilThanValue(entity.name, function (name) { return "-" + name.replace(/ /g, '_'); }, ''); }, ''); };
/**
 * @stable [11.09.2019]
 * @param {IEditableEntity<TValue>} editableEntity
 * @returns {boolean}
 */
exports.isEditableEntityValid = function (editableEntity) {
    return cond_1.ifNotNilThanValue(editableEntity, function () { return R.isNil(editableEntity.valid) || editableEntity.valid === true; }, false);
};
//# sourceMappingURL=entity.js.map