"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definition_1 = require("../definition");
var DYNAMIC_FIELD_SEPARATOR = '-';
/**
 * @stable [27.08.2019]
 * @param {EntityIdT} key
 * @returns {string}
 */
exports.dynamicFieldName = function (key) { return "$$dynamicField" + DYNAMIC_FIELD_SEPARATOR + key; };
/**
 * @stable [28.08.2019]
 * @param {TEntity} object
 * @param {EntityIdT} key
 * @returns {AnyT}
 */
exports.dynamicFieldValue = function (object, key) {
    return Reflect.get(object, exports.dynamicFieldName(key));
};
/**
 * @stable [28.08.2019]
 * @param {TEntity[]} array
 * @param {(itm: TEntity) => EntityIdT} keyAccessor
 * @param {(itm: TEntity) => EntityIdT} valueAccessor
 * @returns {IKeyValue}
 */
exports.fromDynamicFieldsArray = function (array, keyAccessor, valueAccessor) {
    return R.mergeAll(array.map(function (itm) {
        var _a;
        return (_a = {},
            _a[exports.dynamicFieldName(keyAccessor(itm))] = valueAccessor(itm),
            _a);
    }));
};
/**
 * @stable [28.08.2019]
 * @param {EntityIdT[]} array
 * @param {(itm: EntityIdT) => EntityIdT} valueAccessor
 * @returns {IKeyValue}
 */
exports.fromDynamicFieldsIdsArray = function (array, valueAccessor) {
    return exports.fromDynamicFieldsArray(array, function (itm) { return itm; }, valueAccessor);
};
/**
 * @stable [31.08.2019]
 * @param {AnyT} value
 * @returns {AnyT}
 */
exports.toAlwaysDirtyFieldValue = function (value) { return value === definition_1.FIELD_VALUE_TO_CLEAR_DIRTY_CHANGES
    ? definition_1.FIELD_DISPLAY_EMPTY_VALUE
    : value; };
//# sourceMappingURL=field.js.map