import { IEditableEntity, IEditableEntityFormWrapperEntity, IEntityFormEntity, IExtendedEntity, ILifeCycleEntity, IPagedEntity, IPaginatedEntity, IQueryFilterEntity, IQueryFilterWrapperEntity, ToolbarToolsEnum } from '../definition';
import { IActionsDisabledWrapper, IEntity, IKeyValue, IQueryWrapper } from '../definitions.interface';
import { IListEntity, IListWrapperEntity } from '../entities-definitions.interface';
/**
 * @stable [04.09.2019]
 * @param {IEntityFormEntity<TEntity extends IEntity>} entity
 * @returns {IEditableEntity<TEntity extends IEntity>}
 */
export declare const selectEditableEntity: <TEntity extends IEntity = IEntity>(entity: IEntityFormEntity<TEntity>) => IEditableEntity<TEntity>;
/**
 * @stable [04.09.2019]
 * @param {IEditableEntity} entity
 * @returns {TResult}
 */
export declare const selectChanges: <TResult extends IEntity = IEntity>(entity: IEditableEntity<IKeyValue>) => TResult;
/**
 * @stable [04.09.2019]
 * @param {IEntityFormEntity} entity
 * @returns {TResult}
 */
export declare const selectEditableEntityChanges: <TResult extends IEntity = IEntity>(entity: IEntityFormEntity<IEntity>) => TResult;
/**
 * @stable [04.09.2019]
 * @param {IListWrapperEntity} entity
 * @returns {IListEntity}
 */
export declare const selectListEntity: (entity: IListWrapperEntity) => IListEntity;
/**
 * @stable [17.09.2019]
 * @param {ILifeCycleEntity} entity
 * @returns {boolean}
 */
export declare const selectLifeCycleEntityProgress: (entity: ILifeCycleEntity) => boolean;
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {IQueryFilterEntity}
 */
export declare const selectQueryFilterEntity: (entity: IQueryFilterWrapperEntity) => IQueryFilterEntity;
/**
 * @stable [10.09.2019]
 * @param {IQueryFilterEntity} entity
 * @returns {string}
 */
export declare const selectQuery: (entity: IQueryFilterEntity) => string;
/**
 * @stable [04.09.2019]
 * @param {IListEntity} listEntity
 * @returns {TEntity}
 */
export declare const selectSelectedEntity: <TEntity extends IEntity>(listEntity: IListEntity) => TEntity;
/**
 * @stable [04.09.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {TEntity}
 */
export declare const selectListSelectedEntity: <TEntity extends IEntity>(listWrapperEntity: IListWrapperEntity) => TEntity;
/**
 * @stable [30.08.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {string}
 */
export declare const selectFilterWrapperQuery: (entity: IQueryFilterWrapperEntity) => string;
/**
 * @stable [10.09.2019]
 * @param {string} query
 * @returns {IQueryWrapper}
 */
export declare const mapQuery: (query: string) => IQueryWrapper<string>;
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterEntity} filter
 * @returns {IQueryFilterWrapperEntity}
 */
export declare const mapQueryFilterEntity: (filter: IQueryFilterEntity) => IQueryFilterWrapperEntity;
/**
 * @stable [04.09.2019]
 * @param {IEditableEntity<TEntity extends IEntity>} form
 * @returns {IEditableEntityFormWrapperEntity}
 */
export declare const mapEditableEntity: <TEntity extends IEntity = IEntity>(form: IEditableEntity<TEntity>) => IEditableEntityFormWrapperEntity<IKeyValue>;
/**
 * @stable [04.09.2019]
 * @param {IListEntity} list
 * @returns {IListWrapperEntity}
 */
export declare const mapListEntity: (list: IListEntity) => IListWrapperEntity;
/**
 * @stable [10.09.2019]
 * @param {IPagedEntity} entity
 * @returns {IPagedEntity}
 */
export declare const mapPagedEntity: (entity: IPagedEntity) => IPagedEntity;
/**
 * @stable [10.09.2019]
 * @param {IPaginatedEntity} entity
 * @returns {IPaginatedEntity}
 */
export declare const mapPaginatedEntity: (entity: IPaginatedEntity) => IPaginatedEntity;
/**
 * @stable [04.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @returns {IListWrapperEntity}
 */
export declare const mapListWrapperEntity: (listWrapper: IListWrapperEntity) => IListWrapperEntity;
/**
 * @stable [05.09.2019]
 * @param {TEntity} entity
 * @param {IEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
export declare const mapExtendedEntity: <TEntity extends IEntity>(entity: TEntity, editableEntity?: IEditableEntity<IKeyValue>) => IExtendedEntity<TEntity>;
/**
 * @stable [06.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @param {IEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
export declare const mapListSelectedExtendedEntity: <TEntity extends IEntity>(listWrapper: IListWrapperEntity, editableEntity?: IEditableEntity<IKeyValue>) => IExtendedEntity<TEntity>;
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterWrapperEntity} queryFilter
 * @returns {IQueryFilterWrapperEntity}
 */
export declare const mapQueryFilterWrapperEntity: (queryFilter: IQueryFilterWrapperEntity) => IQueryFilterWrapperEntity;
/**
 * @stable [10.09.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {IQueryWrapper}
 */
export declare const mapFilterWrapperQuery: (entity: IQueryFilterWrapperEntity) => IQueryWrapper<string>;
/**
 * @stable [17.09.2019]
 * @param {boolean} actionsDisabled
 * @returns {IActionsDisabledWrapper}
 */
export declare const mapActionsDisabled: (actionsDisabled: boolean) => IActionsDisabledWrapper;
/**
 * @stable [17.09.2019]
 * @param {IListEntity} list
 * @returns {IActionsDisabledWrapper}
 */
export declare const mapListActionsDisabled: (list: IListEntity) => IActionsDisabledWrapper;
/**
 * @stable [17.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @returns {}
 */
export declare const mapListWrapperActionsDisabled: (listWrapper: IListWrapperEntity) => IActionsDisabledWrapper;
/**
 * @stable [18.09.2019]
 * @param {IEditableEntity} editableEntity
 * @returns {ToolbarToolsEnum[]}
 */
export declare const selectEditableEntityToolbarToolsActiveFilter: (editableEntity: IEditableEntity<IKeyValue>) => ToolbarToolsEnum[];
/**
 * @stable [18.09.2019]
 * @param {IEntityFormEntity} entityFormEntity
 * @returns {ToolbarToolsEnum[]}
 */
export declare const selectFormEntityToolbarToolsActiveFilter: (entityFormEntity: IEntityFormEntity<IEntity>) => ToolbarToolsEnum[];
