"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var filter_1 = require("./filter");
var definition_1 = require("../definition");
var definitions_interface_1 = require("../definitions.interface");
var nvl_1 = require("./nvl");
var cond_1 = require("./cond");
var clone_1 = require("./clone");
/**
 * @stable [04.09.2019]
 * @param {IEntityFormEntity<TEntity extends IEntity>} entity
 * @returns {IEditableEntity<TEntity extends IEntity>}
 */
exports.selectEditableEntity = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.form; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [04.09.2019]
 * @param {IEditableEntity} entity
 * @returns {TResult}
 */
exports.selectChanges = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.changes; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [04.09.2019]
 * @param {IEntityFormEntity} entity
 * @returns {TResult}
 */
exports.selectEditableEntityChanges = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return exports.selectChanges(exports.selectEditableEntity(entity)); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [04.09.2019]
 * @param {IListWrapperEntity} entity
 * @returns {IListEntity}
 */
exports.selectListEntity = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.list; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [17.09.2019]
 * @param {ILifeCycleEntity} entity
 * @returns {boolean}
 */
exports.selectLifeCycleEntityProgress = function (entity) { return entity.progress; };
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {IQueryFilterEntity}
 */
exports.selectQueryFilterEntity = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.filter; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [10.09.2019]
 * @param {IQueryFilterEntity} entity
 * @returns {string}
 */
exports.selectQuery = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return nvl_1.trimmedUndefEmpty(entity.query); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [04.09.2019]
 * @param {IListEntity} listEntity
 * @returns {TEntity}
 */
exports.selectSelectedEntity = function (listEntity) {
    return cond_1.ifNotNilThanValue(listEntity, function () { return listEntity.selected; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [04.09.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {TEntity}
 */
exports.selectListSelectedEntity = function (listWrapperEntity) {
    return cond_1.ifNotNilThanValue(exports.selectListEntity(listWrapperEntity), function (list) { return exports.selectSelectedEntity(list); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [30.08.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {string}
 */
exports.selectFilterWrapperQuery = function (entity) { return cond_1.ifNotNilThanValue(exports.selectQueryFilterEntity(entity), function (filterEntity) { return exports.selectQuery(filterEntity); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [10.09.2019]
 * @param {string} query
 * @returns {IQueryWrapper}
 */
exports.mapQuery = function (query) { return filter_1.defValuesFilter({ query: query }); };
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterEntity} filter
 * @returns {IQueryFilterWrapperEntity}
 */
exports.mapQueryFilterEntity = function (filter) {
    return filter_1.defValuesFilter({ filter: filter });
};
/**
 * @stable [04.09.2019]
 * @param {IEditableEntity<TEntity extends IEntity>} form
 * @returns {IEditableEntityFormWrapperEntity}
 */
exports.mapEditableEntity = function (form) {
    return filter_1.defValuesFilter({ form: form });
};
/**
 * @stable [04.09.2019]
 * @param {IListEntity} list
 * @returns {IListWrapperEntity}
 */
exports.mapListEntity = function (list) {
    return filter_1.defValuesFilter({ list: list });
};
/**
 * @stable [10.09.2019]
 * @param {IPagedEntity} entity
 * @returns {IPagedEntity}
 */
exports.mapPagedEntity = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    page: entity.page,
    pageSize: entity.pageSize,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [10.09.2019]
 * @param {IPaginatedEntity} entity
 * @returns {IPaginatedEntity}
 */
exports.mapPaginatedEntity = function (entity) { return cond_1.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter(__assign({}, exports.mapPagedEntity(entity), { totalCount: entity.totalCount })); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [04.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @returns {IListWrapperEntity}
 */
exports.mapListWrapperEntity = function (listWrapper) {
    return exports.mapListEntity(exports.selectListEntity(listWrapper));
};
/**
 * @stable [05.09.2019]
 * @param {TEntity} entity
 * @param {IEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
exports.mapExtendedEntity = function (entity, editableEntity) {
    return filter_1.defValuesFilter({
        entity: __assign({}, entity, exports.selectChanges(editableEntity)),
        entityId: cond_1.ifNotNilThanValue(entity, function () { return entity.id; }, definitions_interface_1.UNDEF_SYMBOL),
        originalEntity: clone_1.shallowClone(entity),
        newEntity: R.isNil(entity) || R.isNil(entity.id),
    });
};
/**
 * @stable [06.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @param {IEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
exports.mapListSelectedExtendedEntity = function (listWrapper, editableEntity) {
    return exports.mapExtendedEntity(exports.selectListSelectedEntity(listWrapper), editableEntity);
};
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterWrapperEntity} queryFilter
 * @returns {IQueryFilterWrapperEntity}
 */
exports.mapQueryFilterWrapperEntity = function (queryFilter) {
    return exports.mapQueryFilterEntity(exports.selectQueryFilterEntity(queryFilter));
};
/**
 * @stable [10.09.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {IQueryWrapper}
 */
exports.mapFilterWrapperQuery = function (entity) {
    return exports.mapQuery(exports.selectFilterWrapperQuery(entity));
};
/**
 * @stable [17.09.2019]
 * @param {boolean} actionsDisabled
 * @returns {IActionsDisabledWrapper}
 */
exports.mapActionsDisabled = function (actionsDisabled) {
    return filter_1.defValuesFilter({ actionsDisabled: actionsDisabled });
};
/**
 * @stable [17.09.2019]
 * @param {IListEntity} list
 * @returns {IActionsDisabledWrapper}
 */
exports.mapListActionsDisabled = function (list) {
    return exports.mapActionsDisabled(exports.selectLifeCycleEntityProgress(list));
};
/**
 * @stable [17.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @returns {}
 */
exports.mapListWrapperActionsDisabled = function (listWrapper) {
    return exports.mapListActionsDisabled(exports.selectListEntity(listWrapper));
};
/**
 * @stable [18.09.2019]
 * @param {IEditableEntity} editableEntity
 * @returns {ToolbarToolsEnum[]}
 */
exports.selectEditableEntityToolbarToolsActiveFilter = function (editableEntity) {
    return cond_1.ifNotEmptyThanValue(exports.selectChanges(editableEntity), function () { return [definition_1.ToolbarToolsEnum.FILTER]; }, []);
};
/**
 * @stable [18.09.2019]
 * @param {IEntityFormEntity} entityFormEntity
 * @returns {ToolbarToolsEnum[]}
 */
exports.selectFormEntityToolbarToolsActiveFilter = function (entityFormEntity) {
    return exports.selectEditableEntityToolbarToolsActiveFilter(exports.selectEditableEntity(entityFormEntity));
};
//# sourceMappingURL=mapper.js.map