"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var URI = require("urijs");
var R = require("ramda");
var definition_1 = require("../definition");
var object_1 = require("./object");
/**
 * @stable [19.09.2019]
 * @param {string} uri
 * @returns {boolean}
 */
exports.isAbsoluteURI = function (uri) { return URI(uri).is('absolute'); };
/**
 * @stable [11.09.2018]
 * @param {IKeyValue} params
 * @returns {string}
 */
exports.buildEncodedURI = function (params) { return encodeURIComponent(btoa(JSON.stringify(params))); };
/**
 * @stable [12.09.2018]
 * @param {string} url
 * @returns {string}
 */
exports.prepareUrl = function (url) { return url.replace(/(\/\/)+/, '/'); };
/**
 * @stable [16.09.2019]
 * @param {ITransportUrlConfigEntity} config
 * @returns {string}
 */
exports.buildTransportUrl = function (config) {
    var urlProvider = config.urlProvider, dataProvider = config.dataProvider, entity = config.entity, settings = config.settings, dateNow = config.dateNow;
    var uniqueParamName = settings.uniqueParamName;
    var method = entity.method;
    var initialUrl = urlProvider(entity);
    var url = new URI(initialUrl);
    if (!R.isNil(uniqueParamName) && entity.noCache !== false) {
        if (!(R.isNil(method) || [definition_1.TransportMethodsEnum.POST].includes(method))) {
            url.addSearch(uniqueParamName, dateNow);
        }
    }
    if (method === definition_1.TransportMethodsEnum.GET) {
        var params = dataProvider(entity);
        if (object_1.isObjectNotEmpty(params)) {
            R.forEachObjIndexed(function (value, key) { return url.addSearch(String(key), value); }, params);
        }
    }
    return url.valueOf();
};
//# sourceMappingURL=url.js.map